pub enum Error {
Show 20 variants
ReqError(Error),
InvalidHeaderError(InvalidHeaderValue),
IoError(Error),
ParseFloatError(ParseFloatError),
UrlParserError(ParseError),
Json(Error),
Qs(Error),
Tungstenite(Error),
TimestampError(SystemTimeError),
UTF8Err(Utf8Error),
BinanceError {
response: BinanceContentError,
},
InvalidListenKey(String),
UnknownSymbol(String),
InvalidOrderError {
msg: String,
},
InvalidPrice,
InvalidPeriod(String),
InternalServerError,
ServiceUnavailable,
Unauthorized,
Msg(String),
}Expand description
First errors are technical errors All unhandled binance content errors are BinanceError The rest are binance content errors that are properly handled Unhandled binance errors are Msg
Variants
ReqError(Error)
InvalidHeaderError(InvalidHeaderValue)
IoError(Error)
ParseFloatError(ParseFloatError)
UrlParserError(ParseError)
Json(Error)
Qs(Error)
Tungstenite(Error)
TimestampError(SystemTimeError)
UTF8Err(Utf8Error)
BinanceError
Fields
response: BinanceContentErrorInvalidListenKey(String)
UnknownSymbol(String)
InvalidOrderError
Fields
msg: StringInvalidPrice
InvalidPeriod(String)
InternalServerError
ServiceUnavailable
Unauthorized
Msg(String)