pub enum OrderType {
    Limit,
    Market,
    StopLoss,
    StopLossLimit,
    TakeProfit,
    TakeProfitLimit,
    LimitMaker,
    Other,
}
Order types, the following restrictions apply LIMIT_MAKER are LIMIT orders that will be rejected if they would immediately match and trade as a taker. STOP_LOSS and TAKE_PROFIT will execute a MARKET order when the stopPrice is reached. Any LIMIT or LIMIT_MAKER type order can be made an iceberg order by sending an icebergQty. Any order with an icebergQty MUST have timeInForce set to GTC. MARKET orders using quantity specifies how much a user wants to buy or sell based on the market price. MARKET orders using quoteOrderQty specifies the amount the user wants to spend (when buying) or receive (when selling) of the quote asset; the correct quantity will be determined based on the market liquidity and quoteOrderQty. MARKET orders using quoteOrderQty will not break LOT_SIZE filter rules; the order will execute a quantity that will have the notional value as close as possible to quoteOrderQty.

Variants

Limit

Market

StopLoss

StopLossLimit

TakeProfit

TakeProfitLimit

LimitMaker

Other