pub struct CoinWithdrawalQuery {
pub coin: String,
pub withdraw_order_id: Option<String>,
pub network: Option<String>,
pub address: String,
pub address_tag: Option<String>,
pub amount: f64,
pub transaction_fee_flag: Option<bool>,
pub name: Option<String>,
pub wallet_type: u8,
}Fields
coin: Stringwithdraw_order_id: Option<String>client id for withdraw
network: Option<String>address: Stringaddress_tag: Option<String>Secondary address identifier for coins like XRP,XMR etc.
amount: f64transaction_fee_flag: Option<bool>When making internal transfer, true for returning the fee to the destination account; false for returning the fee back to the departure account. Default false.
name: Option<String>Description of the address. Space in name should be encoded into %20.
wallet_type: u8The wallet type for withdraw,0: spot wallet. 1: funding wallet. Default: spot wallet