Enum OrderStatus

pub enum OrderStatus {
    New,
    PendingNew,
    PartiallyFilled,
    Filled,
    Canceled,
    PendingCancel,
    Rejected,
    Expired,
    ExpiredInMatch,
}
Order status.

Variants



New

The order has been accepted by the engine.



PendingNew

The order is in a pending phase until the working order of an order list has been fully filled.



PartiallyFilled

A part of the order has been filled.



Filled

The order has been completed.



Canceled

The order has been canceled by the user.



PendingCancel

Currently unused



Rejected

The order was not accepted by the engine and not processed.



Expired

The order was canceled according to the order type’s rules (e.g. LIMIT FOK orders with no fill, LIMIT IOC or MARKET orders that partially fill) or by the exchange, (e.g. orders canceled during liquidation, orders canceled during maintenance)



ExpiredInMatch

The order was expired by the exchange due to STP. (e.g. an order with EXPIRE_TAKER will match with existing orders on the book with the same account or same tradeGroupId)