pub struct NewOrderResponseAck {Show 15 fields
pub symbol: String,
pub order_id: i64,
pub order_list_id: i64,
pub client_order_id: String,
pub transact_time: Timestamp,
pub iceberg_qty: Option<Decimal>,
pub prevented_match_id: Option<i64>,
pub prevented_quantity: Option<Decimal>,
pub stop_price: Option<Decimal>,
pub strategy_id: Option<i64>,
pub strategy_type: Option<i64>,
pub trailing_delta: Option<i64>,
pub trailing_time: Option<i64>,
pub used_sor: Option<bool>,
pub working_floor: Option<WorkingFloor>,
}Fields
symbol: Stringorder_id: i64order_list_id: i64Unless it’s part of an order list, value will be -1
client_order_id: Stringtransact_time: Timestampiceberg_qty: Option<Decimal>Quantity for the iceberg order Appears only if the parameter icebergQty was sent in the request.
prevented_match_id: Option<i64>When used in combination with symbol, can be used to query a prevented match. Appears only if the order expired due to STP.
prevented_quantity: Option<Decimal>Order quantity that expired due to STP Appears only if the order expired due to STP.
stop_price: Option<Decimal>Price when the algorithmic order will be triggered Appears for STOP_LOSS. TAKE_PROFIT, STOP_LOSS_LIMIT and TAKE_PROFIT_LIMIT orders.
strategy_id: Option<i64>Can be used to label an order that’s part of an order strategy. Appears if the parameter was populated in the request.
strategy_type: Option<i64>Can be used to label an order that is using an order strategy. Appears if the parameter was populated in the request.
trailing_delta: Option<i64>Delta price change required before order activation Appears for Trailing Stop Orders.
trailing_time: Option<i64>Time when the trailing order is now active and tracking price changes Appears only for Trailing Stop Orders.
used_sor: Option<bool>Field that determines whether order used SOR Appears when placing orders using SOR
working_floor: Option<WorkingFloor>Field that determines whether the order is being filled by the SOR or by the order book the order was submitted to. Appears when placing orders using SOR