PrivateClient

Struct PrivateClient 

pub struct PrivateClient { /* private fields */ }

Implementations

Source

impl PrivateClient

pub fn new(cfg: PrivateConfig) -> Self

Source

impl PrivateClient

pub async fn new_order( &self, params: NewOrderRequest, ) -> Result<Response<NewOrderResponse>, Error>

Send in a new order. This adds 1 order to the EXCHANGE_MAX_ORDERS filter and the MAX_NUM_ORDERS filter.

Other info: Any LIMIT or LIMIT_MAKER type order can be made an iceberg order by sending an icebergQty. Any order with an icebergQty MUST have timeInForce set to GTC. For STOP_LOSS, STOP_LOSS_LIMIT, TAKE_PROFIT_LIMIT and TAKE_PROFIT orders, trailingDelta can be combined with stopPrice. MARKET orders using quoteOrderQty will not break LOT_SIZE filter rules; the order will execute a quantity that will have the notional value as close as possible to quoteOrderQty. Trigger order price rules against market price for both MARKET and LIMIT versions: Price above market price: STOP_LOSS BUY, TAKE_PROFIT SELL Price below market price: STOP_LOSS SELL, TAKE_PROFIT BUY

pub async fn test_new_order( &self, params: NewOrderRequest, ) -> Result<Response<TestCommissionRates>, Error>

Test new order creation and signature/recvWindow long. Creates and validates a new order but does not send it into the matching engine.

Source

impl PrivateClient

pub async fn account_information( &self, params: GetAccountInformationParams, ) -> Result<Response<AccountInformation>, Error>

Get current account information.

pub async fn query_order( &self, params: QueryOrderParams, ) -> Result<Response<Order>, Error>

Check an order’s status. Notes: Either orderId or origClientOrderId must be sent. If both orderId and origClientOrderId are provided, the orderId is searched first, then the origClientOrderId from that result is checked against that order. If both conditions are not met the request will be rejected. For some historical orders cummulativeQuoteQty will be < 0, meaning the data is not available at this time.