AccountClient

Struct AccountClient 

pub struct AccountClient { /* private fields */ }

Implementations

Source

impl AccountClient

pub fn new( base_url: String, api_key: SensitiveString, api_secret: SensitiveString, ) -> Self

Source

impl AccountClient

pub async fn account_information( &self, params: GetAccountInformationParams, ) -> Result<Response<AccountInformation>, Error>

Get current account information.

pub async fn query_order( &self, params: QueryOrderParams, ) -> Result<Response<Order>, Error>

Check an order’s status. Notes: Either orderId or origClientOrderId must be sent. If both orderId and origClientOrderId are provided, the orderId is searched first, then the origClientOrderId from that result is checked against that order. If both conditions are not met the request will be rejected. For some historical orders cummulativeQuoteQty will be < 0, meaning the data is not available at this time.