pub struct Order {Show 20 fields
pub symbol: String,
pub order_id: i64,
pub order_list_id: i64,
pub client_order_id: String,
pub price: Decimal,
pub orig_qty: Decimal,
pub executed_qty: Decimal,
pub cummulative_quote_qty: Decimal,
pub status: OrderStatus,
pub time_in_force: TimeInForce,
pub order_type: OrderType,
pub side: OrderSide,
pub stop_price: Option<Decimal>,
pub iceberg_qty: Option<Decimal>,
pub time: Timestamp,
pub update_time: Timestamp,
pub is_working: bool,
pub working_time: Timestamp,
pub orig_quote_order_qty: Decimal,
pub self_trade_prevention_mode: STPMode,
}Fields
symbol: Stringorder_id: i64order_list_id: i64This field will always have a value of -1 if not an order list.
client_order_id: Stringprice: Decimalorig_qty: Decimalexecuted_qty: Decimalcummulative_quote_qty: Decimalstatus: OrderStatustime_in_force: TimeInForceorder_type: OrderTypeside: OrderSidestop_price: Option<Decimal>Price when the algorithmic order will be triggered Appears for STOP_LOSS. TAKE_PROFIT, STOP_LOSS_LIMIT and TAKE_PROFIT_LIMIT orders.
iceberg_qty: Option<Decimal>Quantity for the iceberg order Appears only if the parameter icebergQty was sent in the request.
time: Timestampupdate_time: Timestampis_working: boolworking_time: Timestamporig_quote_order_qty: Decimalself_trade_prevention_mode: STPModeTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Order
impl<'de> Deserialize<'de> for Order
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for Order