Stream

Struct Stream 

pub struct Stream<C, M>
where C: Serialize + Send + Debug + 'static, M: ReceivedMessage + DeserializeOwned + Send + Debug + 'static,
{ /* private fields */ }
General WSS information A single connection to stream.binance.com is only valid for 24 hours; expect to be disconnected at the 24 hour mark. A serverShutdown event will be sent 10 minutes before disconnection. Please establish a new connection as soon as possible to prevent interruption. The WebSocket server will send a ping frame every 20 seconds. If the WebSocket server does not receive a pong frame back from the connection within a minute the connection will be disconnected. When you receive a ping, you must send a pong with a copy of ping’s payload as soon as possible. Unsolicited pong frames are allowed, but will not prevent disconnection. It is recommended that the payload for these pong frames are empty.

Implementations

Source

impl<C, M> Stream<C, M>
where C: Serialize + Send + Debug + 'static, M: ReceivedMessage + DeserializeOwned + Send + Debug + 'static,

pub fn new(config: Config) -> (Handle<C>, Receiver<Event<M>>)