pub struct OrderRequest {
    pub symbol: String,
    pub side: OrderSide,
    pub order_type: OrderType,
    pub time_in_force: Option<TimeInForce>,
    pub quantity: Option<f64>,
    pub quote_order_qty: Option<f64>,
    pub price: Option<f64>,
    pub new_client_order_id: Option<String>,
    pub stop_price: Option<f64>,
    pub iceberg_qty: Option<f64>,
    pub new_order_resp_type: Option<OrderResponse>,
    pub recv_window: Option<u64>,
}
Order Request perform an order for the account

Fields

symbol: Stringside: OrderSideorder_type: OrderTypetime_in_force: Option<TimeInForce>quantity: Option<f64>quote_order_qty: Option<f64>price: Option<f64>new_client_order_id: Option<String>

A unique id for the order, automatically generated if not sent.

stop_price: Option<f64>

Used with stop loss, stop loss limit, take profit and take profit limit order types.

iceberg_qty: Option<f64>

Used with limit, stop loss limit and take profit limit to create an iceberg order.

new_order_resp_type: Option<OrderResponse>

Set the response json, market and limit default to full others to ack.

recv_window: Option<u64>

Cannot be greater than 60000