Enum binance::errors::Error[][src]

pub enum Error {
Show 20 variants ReqError(Error), InvalidHeaderError(InvalidHeaderValue), IoError(Error), ParseFloatError(ParseFloatError), UrlParserError(ParseError), Json(Error), Qs(Error), Tungstenite(Error), TimestampError(SystemTimeError), UTF8Err(Utf8Error), BinanceError { response: BinanceContentError, }, InvalidListenKey(String), UnknownSymbol(String), InvalidOrderError { msg: String, }, InvalidPrice, InvalidPeriod(String), InternalServerError, ServiceUnavailable, Unauthorized, Msg(String),
}
First errors are technical errors All unhandled binance content errors are BinanceError The rest are binance content errors that are properly handled Unhandled binance errors are Msg

Variants

ReqError(Error)

Tuple Fields of ReqError

0: Error
InvalidHeaderError(InvalidHeaderValue)

Tuple Fields of InvalidHeaderError

0: InvalidHeaderValue
IoError(Error)

Tuple Fields of IoError

0: Error
ParseFloatError(ParseFloatError)

Tuple Fields of ParseFloatError

0: ParseFloatError
UrlParserError(ParseError)

Tuple Fields of UrlParserError

0: ParseError
Json(Error)

Tuple Fields of Json

0: Error
Qs(Error)

Tuple Fields of Qs

0: Error
Tungstenite(Error)

Tuple Fields of Tungstenite

0: Error
TimestampError(SystemTimeError)

Tuple Fields of TimestampError

0: SystemTimeError
UTF8Err(Utf8Error)

Tuple Fields of UTF8Err

0: Utf8Error
BinanceError

Fields of BinanceError

response: BinanceContentError
InvalidListenKey(String)

Tuple Fields of InvalidListenKey

0: String
UnknownSymbol(String)

Tuple Fields of UnknownSymbol

0: String
InvalidOrderError

Fields of InvalidOrderError

msg: String
InvalidPrice
InvalidPeriod(String)

Tuple Fields of InvalidPeriod

0: String
InternalServerError
ServiceUnavailable
Unauthorized
Msg(String)

Tuple Fields of Msg

0: String