Enum binance::errors::Error [−][src]
pub enum Error {
Show 20 variants
ReqError(Error),
InvalidHeaderError(InvalidHeaderValue),
IoError(Error),
ParseFloatError(ParseFloatError),
UrlParserError(ParseError),
Json(Error),
Qs(Error),
Tungstenite(Error),
TimestampError(SystemTimeError),
UTF8Err(Utf8Error),
BinanceError {
response: BinanceContentError,
},
InvalidListenKey(String),
UnknownSymbol(String),
InvalidOrderError {
msg: String,
},
InvalidPrice,
InvalidPeriod(String),
InternalServerError,
ServiceUnavailable,
Unauthorized,
Msg(String),
}Expand description
First errors are technical errors All unhandled binance content errors are BinanceError The rest are binance content errors that are properly handled Unhandled binance errors are Msg
Variants
ReqError(Error)Tuple Fields of ReqError
0: ErrorInvalidHeaderError(InvalidHeaderValue)Tuple Fields of InvalidHeaderError
IoError(Error)Tuple Fields of IoError
0: ErrorParseFloatError(ParseFloatError)Tuple Fields of ParseFloatError
UrlParserError(ParseError)Tuple Fields of UrlParserError
0: ParseErrorJson(Error)Tuple Fields of Json
0: ErrorQs(Error)Tuple Fields of Qs
0: ErrorTungstenite(Error)Tuple Fields of Tungstenite
0: ErrorTimestampError(SystemTimeError)Tuple Fields of TimestampError
UTF8Err(Utf8Error)Tuple Fields of UTF8Err
0: Utf8ErrorFields of BinanceError
response: BinanceContentErrorInvalidListenKey(String)Tuple Fields of InvalidListenKey
0: StringUnknownSymbol(String)Tuple Fields of UnknownSymbol
0: StringFields of InvalidOrderError
msg: StringInvalidPeriod(String)Tuple Fields of InvalidPeriod
0: StringMsg(String)Tuple Fields of Msg
0: StringTrait Implementations
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.
Performs the conversion.