Enum binance::rest_model::OrderStatus
source · [−]pub enum OrderStatus {
New,
PartiallyFilled,
Filled,
Canceled,
PendingCancel,
Rejected,
Expired,
Trade,
}Expand description
Status of an order, this can typically change over time
Variants
New
The order has been accepted by the engine.
PartiallyFilled
A part of the order has been filled.
Filled
The order has been completely filled.
Canceled
The order has been canceled by the user.
PendingCancel
(currently unused)
Rejected
The order was not accepted by the engine and not processed.
Expired
The order was canceled according to the order type’s rules (e.g. LIMIT FOK orders with no fill, LIMIT IOC or MARKET orders that partially fill) or by the exchange, (e.g. orders canceled during liquidation, orders canceled during maintenance)
Trade
Part of the order or all of the order’s quantity has filled.