Struct Client

pub struct Client { /* private fields */ }

Implementations

Source

impl Client

pub fn new(cfg: ClientConfig) -> Self

Source

impl Client

pub async fn test_connectivity( &self, ) -> Result<Response<TestConnectivity>, Error>

Test connectivity to the Rest API.

pub async fn get_server_time(&self) -> Result<Response<ServerTime>, Error>

pub async fn get_exchange_info( &self, params: GetExchangeInfoParams, ) -> Result<Response<ExchangeInfo>, Error>

Source

impl Client

pub async fn get_order_book( &self, params: GetOrderBookParams, ) -> Result<Response<OrderBook>, Error>

pub async fn recent_trades_list( &self, params: GetRecentTradesParams, ) -> Result<Response<Vec<RecentTrade>>, Error>

Get recent trades.

pub async fn old_trade_lookup( &self, params: GetOlderTradesParams, ) -> Result<Response<Vec<RecentTrade>>, Error>

Get older trades.

pub async fn aggregate_trades_list( &self, params: GetAggregateTradesParams, ) -> Result<Response<Vec<AggregateTrade>>, Error>

Compressed/Aggregate trades list. Get compressed, aggregate trades. Trades that fill at the time, from the same taker order, with the same price will have the quantity aggregated.

If fromId, startTime, and endTime are not sent, the most recent aggregate trades will be returned.

pub async fn get_kline_list( &self, params: GetKlineListParams, ) -> Result<Response<Vec<Kline>>, Error>

Kline/candlestick bars for a symbol. Klines are uniquely identified by their open time.

If startTime and endTime are not sent, the most recent klines are returned. Supported values for timeZone: Hours and minutes (e.g. -1:00, 05:45) Only hours (e.g. 0, 8, 4) Accepted range is strictly [-12:00 to +14:00] inclusive If timeZone provided, kline intervals are interpreted in that timezone instead of UTC. Note that startTime and endTime are always interpreted in UTC, regardless of timeZone.

pub async fn get_ui_kline_list( &self, params: GetKlineListParams, ) -> Result<Response<Vec<Kline>>, Error>

UIKlines

The request is similar to klines having the same parameters and response. uiKlines return modified kline data, optimized for presentation of candlestick charts.

If startTime and endTime are not sent, the most recent klines are returned. Supported values for timeZone: Hours and minutes (e.g. -1:00, 05:45) Only hours (e.g. 0, 8, 4) Accepted range is strictly [-12:00 to +14:00] inclusive If timeZone provided, kline intervals are interpreted in that timezone instead of UTC. Note that startTime and endTime are always interpreted in UTC, regardless of timeZone.

pub async fn get_current_average_price( &self, params: GetCurrentAveragePriceParams, ) -> Result<Response<CurrentAveragePrice>, Error>

Current average price for a symbol.